==> unitrack-6.x-1.1.tar.gz: unitrack/js/client.js <==
/*
 * zeepzap tracker version 1.1
 *
 * Copyright (c) 2010 zeepzap team (zeepzap.info)
 * Dual licensed under the MIT (MIT-LICENSE.txt)
 * and GPL version 2.0 (GPL-LICENSE.txt) licenses.
 *
 * Date: 2010-08-03
 * Rev: 2
 */
var zeepzap = zeepzap ? zeepzap : new Object();
var _gaq = _gaq || [];
var clicky_custom = clicky_custom ? clicky_custom : new Object();

// Object constructor
zeepzap.tracker = new Object();
zeepzap.tracker.workers = ['self'];
zeepzap.tracker.options = {'autoload':true};

zeepzap.tracker.init = function(options) {
 if (typeof(zeepzap.tracker.ready) != 'undefined') {
  return;
 };
 zeepzap.tracker.ready = 1; 
 if (options.workers.ga) {
   this.workers.push('ga');
   this.options.ga = options.workers.ga;
 }
 if (options.workers.clicky) {
   this.workers.push('clicky');
   this.options.clicky = options.workers.clicky;
 }
 if (this.options.autoload) {
  this.track('pageview');
 };
};

zeepzap.tracker.detectFlash = function() {
	var flashData = {installed:false};
	if(navigator.plugins && navigator.plugins.length>0){
	 var type = 'application/x-shockwave-flash';
	 var mimeTypes = navigator.mimeTypes;
	 if(mimeTypes && mimeTypes[type] && mimeTypes[type].enabledPlugin && mimeTypes[type].enabledPlugin.description){
	  var version = mimeTypes[type].enabledPlugin.description;
	  var descParts = version.split(/ +/);
	  var majorMinor = descParts[2].split(/\./);
	  var revisionStr = descParts[3];
	  var versionObj = {
	   "raw":version,
	   "major":parseInt(majorMinor[0], 10),
	   "minor":parseInt(majorMinor[1], 10) 
	  };
	     
      flashData.raw = version;
      flashData.major = versionObj.major;
      flashData.minor = versionObj.minor; 
      flashData.installed = true;
	 }
	} else if(navigator.appVersion.indexOf("Mac")==-1 && window.execScript){
	 var version = -1;
	 var getActiveXObject = function(name){
		 var obj = -1;
		 try{
		 obj = new ActiveXObject(name);
		 }catch(err){
		 obj = {activeXError:true};
		 }
		 return obj;
		 };	
	 var getActiveXVersion = function(activeXObj){
		 var version = -1;
		 try{
		 version = activeXObj.GetVariable("$version");
		 }catch(err){}
		 return version;
		 };	 
	 var activeXDetectRules = [{
		  "name":"ShockwaveFlash.ShockwaveFlash.7",
		  "version":function(obj){
		   return getActiveXVersion(obj);
		  }
		 },
		 {
		  "name":"ShockwaveFlash.ShockwaveFlash.6",
		  "version":function(obj){
		   var version = "6,0,21";
		   try{
		   obj.AllowScriptAccess = "always";
		    version = getActiveXVersion(obj);
		   }catch(err){}
		    return version;
		  }
		 },
		 {
		  "name":"ShockwaveFlash.ShockwaveFlash",
		  "version":function(obj){
		   return getActiveXVersion(obj);
		  }
		 }
	 ];
	 for(var i=0; i<activeXDetectRules.length && version==-1; i++){
	  var obj = getActiveXObject(activeXDetectRules[i].name);
	  if(!obj.activeXError){
	 	 flashData.installed = true;
	   	 version = activeXDetectRules[i].version(obj);
	   	 if(version!=-1){
	   		 var versionArray = version.split(",");//replace with regex
	   		 var versionObj = {
	   	            "raw":version,
	   	            "major":parseInt(versionArray[0].split(" ")[1], 10),
	   	            "minor":parseInt(versionArray[1], 10),
	   	            "revision":parseInt(versionArray[2], 10),
	   	            "revisionStr":versionArray[2]
	   	     };
    		 flashData.raw = versionObj.raw;
             flashData.major = versionObj.major;
             flashData.minor = versionObj.minor; 
             flashData.revision = versionObj.revision;
             flashData.revisionStr = versionObj.revisionStr;
         }
	  }
	 }
	}
	return flashData;
};

zeepzap.tracker.session_data = (-1);

zeepzap.tracker.track = function (ttype) {
 var rdata = {'ts':new Date().getTime(),'vid':'', 'sid':'','path':window.location.pathname};
 if (typeof(window.localStorage)!='undefined' && typeof(window.localStorage.unitrack_vid)!='undefined' && window.localStorage.unitrack_vid) {
  rdata.vid = window.localStorage.unitrack_vid;
 }
 if (typeof(window.sessionStorage)!='undefined' && typeof(window.sessionStorage.unitrack_sid)!='undefined' && window.sessionStorage.unitrack_sid) {
  rdata.sid = window.sessionStorage.unitrack_sid;
 }
 else {
  rdata.javaEnabled = navigator.javaEnabled().toString();
  rdata.os = navigator.platform;
  rdata.ua = navigator.userAgent;
  rdata.resolution = screen.width + 'x' + screen.height;
  flashData = this.detectFlash();
  rdata.flash = flashData.installed ? (flashData.major + '.' + flashData.minor) : 'none';
 }
 $.post(Drupal.settings.zeepzap.tracker, rdata, function(data) {
  if(typeof(data.visitor)!='undefined' && data.visitor.length>10) 
   window.localStorage.unitrack_vid = data.visitor;
  else
   data.visitor = rdata.vid;
  if(typeof(data.session)!='undefined' && data.session.length>10)
   window.sessionStorage.unitrack_sid = data.session;
  else
   data.session = rdata.sid;
  zeepzap.tracker.session_data = data;
  if (zeepzap.tracker.options.clicky) {
   zeepzap.tracker._track_clicky(data);
  }
  if (zeepzap.tracker.options.ga) {
   zeepzap.tracker._track_ga(data);
  }
 },'json');	
};

zeepzap.tracker._track_ga = function(session_data) {
  _gaq.push(['_setAccount', this.options.ga.account]);
  
  if(typeof(session_data.segmentation)!='undefined') {
    _gaq.push('_setVar', session_data.segmentation);
  }
  
  _gaq.push(['_trackPageview']);
		  
  var ga = document.createElement('script');
  ga.type = 'text/javascript'; 
  ga.async = true;
  ga.src = ('https:' == document.location.protocol ? 'https://ssl' : 'http://www') + '.google-analytics.com/ga.js';
  var s = document.getElementsByTagName('head')[0]; 
  s.parentNode.insertBefore(ga, s);
};

zeepzap.tracker._track_clicky = function(session_data) {
  var scr = document.createElement('script');
  scr.type = 'text/javascript';
  scr.options = Drupal.settings.zeepzap.workers.clicky;
  scr.onload = function() {
	clicky_custom.session = session_data;
	clicky.init(this.options.account);
  };
  scr.src = 'https://static.getclicky.com/js';
  var headID = document.getElementsByTagName("head")[0];         
  headID.appendChild(scr);
};

$(function(){
 zeepzap.tracker.init(Drupal.settings.zeepzap);
});

==> unitrack-6.x-1.2.tar.gz: unitrack/js/client.js <==
/*
 * zeepzap tracker version 1.2
 *
 * Copyright (c) 2010 zeepzap team (zeepzap.info)
 * Dual licensed under the MIT (MIT-LICENSE.txt)
 * and GPL version 2.0 (GPL-LICENSE.txt) licenses.
 *
 * Date: 2010-08-03
 * Rev: 2
 */
var zeepzap = zeepzap ? zeepzap : new Object();
var _gaq = _gaq || [];
var clicky_custom = clicky_custom ? clicky_custom : new Object();

// Object constructor
zeepzap.tracker = new Object();
zeepzap.tracker.workers = ['self'];
zeepzap.tracker.options = {'autoload':true};

zeepzap.tracker.init = function(options) {
 if (typeof(zeepzap.tracker.ready) != 'undefined') {
  return;
 };
 if (options.workers.ga) {
   this.workers.push('ga');
   this.options.ga = options.workers.ga;
 }
 if (options.workers.clicky) {
   this.workers.push('clicky');
   this.options.clicky = options.workers.clicky;
 }
 zeepzap.tracker.ready = 1; 
 if (this.options.autoload) {
  this.track('pageview');
 };
};

zeepzap.tracker.detectFlash = function() {
	var flashData = {installed:false};
	if(navigator.plugins && navigator.plugins.length>0){
	 var type = 'application/x-shockwave-flash';
	 var mimeTypes = navigator.mimeTypes;
	 if(mimeTypes && mimeTypes[type] && mimeTypes[type].enabledPlugin && mimeTypes[type].enabledPlugin.description){
	  var version = mimeTypes[type].enabledPlugin.description;
	  var descParts = version.split(/ +/);
	  var majorMinor = descParts[2].split(/\./);
	  var revisionStr = descParts[3];
	  var versionObj = {
	   "raw":version,
	   "major":parseInt(majorMinor[0], 10),
	   "minor":parseInt(majorMinor[1], 10) 
	  };
	     
      flashData.raw = version;
      flashData.major = versionObj.major;
      flashData.minor = versionObj.minor; 
      flashData.installed = true;
	 }
	} else if(navigator.appVersion.indexOf("Mac")==-1 && window.execScript){
	 var version = -1;
	 var getActiveXObject = function(name){
		 var obj = -1;
		 try{
		 obj = new ActiveXObject(name);
		 }catch(err){
		 obj = {activeXError:true};
		 }
		 return obj;
		 };	
	 var getActiveXVersion = function(activeXObj){
		 var version = -1;
		 try{
		 version = activeXObj.GetVariable("$version");
		 }catch(err){}
		 return version;
		 };	 
	 var activeXDetectRules = [{
		  "name":"ShockwaveFlash.ShockwaveFlash.7",
		  "version":function(obj){
		   return getActiveXVersion(obj);
		  }
		 },
		 {
		  "name":"ShockwaveFlash.ShockwaveFlash.6",
		  "version":function(obj){
		   var version = "6,0,21";
		   try{
		   obj.AllowScriptAccess = "always";
		    version = getActiveXVersion(obj);
		   }catch(err){}
		    return version;
		  }
		 },
		 {
		  "name":"ShockwaveFlash.ShockwaveFlash",
		  "version":function(obj){
		   return getActiveXVersion(obj);
		  }
		 }
	 ];
	 for(var i=0; i<activeXDetectRules.length && version==-1; i++){
	  var obj = getActiveXObject(activeXDetectRules[i].name);
	  if(!obj.activeXError){
	 	 flashData.installed = true;
	   	 version = activeXDetectRules[i].version(obj);
	   	 if(version!=-1){
	   		 var versionArray = version.split(",");//replace with regex
	   		 var versionObj = {
	   	            "raw":version,
	   	            "major":parseInt(versionArray[0].split(" ")[1], 10),
	   	            "minor":parseInt(versionArray[1], 10),
	   	            "revision":parseInt(versionArray[2], 10),
	   	            "revisionStr":versionArray[2]
	   	     };
    		 flashData.raw = versionObj.raw;
             flashData.major = versionObj.major;
             flashData.minor = versionObj.minor; 
             flashData.revision = versionObj.revision;
             flashData.revisionStr = versionObj.revisionStr;
         }
	  }
	 }
	}
	return flashData;
};

zeepzap.tracker.session_data = (-1);

zeepzap.tracker.track = function (ttype, url) {
 switch(ttype) {
  case 'pageview':
   this._pageView();
   break;
  case 'virtual':
  case 'virt':
   if(typeof(this._track_ga) != 'undefined') {
    this._track_ga({'virtual_pageview':url});
   }
   if(typeof(this._track_clicky) != 'undefined') {
    this._clicky_log(url);
   }
   break;
 }
};

zeepzap.tracker._pageView = function () {
 var rdata = {'ts':new Date().getTime(),'vid':'', 'sid':'','path':window.location.pathname};
 if (typeof(window.localStorage)!='undefined' && typeof(window.localStorage.unitrack_vid)!='undefined' && window.localStorage.unitrack_vid) {
  rdata.vid = window.localStorage.unitrack_vid;
 }
 if (typeof(window.sessionStorage)!='undefined' && typeof(window.sessionStorage.unitrack_sid)!='undefined' && window.sessionStorage.unitrack_sid) {
  rdata.sid = window.sessionStorage.unitrack_sid;
 }
 else {
  rdata.javaEnabled = navigator.javaEnabled().toString();
  rdata.os = navigator.platform;
  rdata.ua = navigator.userAgent;
  rdata.resolution = screen.width + 'x' + screen.height;
  flashData = this.detectFlash();
  rdata.flash = flashData.installed ? (flashData.major + '.' + flashData.minor) : 'none';
 }
 $.post(Drupal.settings.zeepzap.tracker, rdata, function(data) {
  if(typeof(data.visitor)!='undefined' && typeof(window.localStorage)!='undefined' && data.visitor.length>10) 
   window.localStorage.unitrack_vid = data.visitor;
  else
   data.visitor = rdata.vid;
  if(typeof(window.sessionStorage)!='undefined' && typeof(data.session)!='undefined' && data.session.length>10)
   window.sessionStorage.unitrack_sid = data.session;
  else
   data.session = rdata.sid;
  zeepzap.tracker.session_data = data;
  if (zeepzap.tracker.options.clicky) {
   zeepzap.tracker._track_clicky(data);
  }
  if (zeepzap.tracker.options.ga) {
   zeepzap.tracker._track_ga(data);
  }
 },'json');	
};

zeepzap.tracker._track_ga = function(session_data) {
  _gaq.push(['_setAccount', this.options.ga.account]);
  
  if(typeof(session_data.segmentation)!='undefined') {
    _gaq.push(['_setVar', session_data.segmentation]);
  }
  if(typeof(session_data.virtual_pageview)!='undefined') {
    _gaq.push(['_trackPageview', session_data.virtual_pageview]);
  }
  else {
    _gaq.push(['_trackPageview']);
  }
		  
  var ga = document.createElement('script');
  ga.type = 'text/javascript'; 
  ga.async = true;
  ga.src = ('https:' == document.location.protocol ? 'https://ssl' : 'http://www') + '.google-analytics.com/ga.js';
  var s = document.getElementsByTagName('head')[0]; 
  s.parentNode.insertBefore(ga, s);
};

zeepzap.tracker._track_clicky = function(session_data) {
  var scr = document.createElement('script');
  scr.type = 'text/javascript';
  scr.options = Drupal.settings.zeepzap.workers.clicky;
  scr.onload = function() {
	clicky_custom.session = session_data;
	clicky.init(this.options.account);
  };
  scr.src = 'https://static.getclicky.com/js';
  var headID = document.getElementsByTagName("head")[0];         
  headID.appendChild(scr);
};

zeepzap.tracker._clicky_log = function(log_message) {
 if (typeof(clicky) != 'undefined')
 clicky.log(log_message);
};

$(function(){
 zeepzap.tracker.init(Drupal.settings.zeepzap);
});
